"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const execa_1 = tslib_1.__importDefault(require("execa"));
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const constants_1 = require("../../constants");
class FrameworkLink extends command_1.Command {
    async run() {
        const { flags } = this.parse(FrameworkLink);
        const fwPath = path_1.default
            .join(flags.base_root, constants_1.fwDirName, 'src')
            .replace(/\/$/, '');
        const deployPath = path_1.default.join(fwPath, flags.deploy_path).replace(/\/$/, '');
        const docPathRelativeToFw = path_1.default
            .relative(path_1.default.join(deployPath, '..'), path_1.default.join(flags.base_root, flags.doc_version))
            .replace(/\/$/, '');
        this.debug(`fwPath=${fwPath}`);
        this.debug(`deployPath=${deployPath}`);
        this.debug(`docPathRelativeToFw=${docPathRelativeToFw}`);
        if (!fs_1.default.existsSync(fwPath)) {
            throw new Error(`Framework not found in ${fwPath}`);
        }
        cli_ux_1.default.action.start('Linking local docs into framework');
        await execa_1.default('rm', ['-rf', `${deployPath}`], {});
        await execa_1.default('ln', ['-s', docPathRelativeToFw, deployPath], {});
        cli_ux_1.default.action.stop('Done!');
    }
}
exports.default = FrameworkLink;
FrameworkLink.description = 'Links a local version of the docs to the installed framework';
FrameworkLink.flags = {
    help: command_1.flags.help({ char: 'h' }),
    deploy_path: command_1.flags.string({
        char: 'd',
        description: 'The path where the local version of the docs will be deployed (e.g. /sdk/js/6/) - env: $DEPLOY_PATH',
        default: process.env.DEPLOY_PATH,
        required: true
    }),
    doc_version: command_1.flags.string({
        char: 'v',
        description: 'The local version of the docs to be linked, relative to the base doc root (e.g. 6/) - env: $DOC_VERSION',
        default: process.env.DOC_VERSION,
        required: true
    }),
    base_root: command_1.flags.string({
        char: 'b',
        description: 'The local root of the docs',
        default: constants_1.docPathInRepo
    })
};
