"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const build_1 = require("../repo/build");
const common_1 = require("../../common");
const listr_1 = tslib_1.__importDefault(require("listr"));
const path_1 = require("path");
const constants_1 = require("../../constants");
class ReposBuild extends command_1.Command {
    async run() {
        const { flags } = this.parse(ReposBuild);
        cli_ux_1.default.action.start('Fetching repository list');
        const selectedRepos = await common_1.getRepositories(flags.repositories ? flags.repositories.split(',') : []);
        cli_ux_1.default.action.stop(`Found ${selectedRepos.length} repos`);
        const tasks = new listr_1.default([
            {
                title: `Building repositories into ${flags.repos_path}`,
                task: () => new listr_1.default(selectedRepos.map(repo => ({
                    title: repo.name,
                    task: () => build_1.buildRepo(path_1.join(flags.repos_path, repo.name, repo.doc_root || constants_1.docPathInRepo), repo.doc_version, repo.deploy_path, repo.name)
                })))
            }
        ]);
        await tasks.run();
    }
}
exports.default = ReposBuild;
ReposBuild.description = 'Build a list of repositories';
ReposBuild.flags = {
    help: command_1.flags.help({ char: 'h' }),
    repositories: command_1.flags.string({
        char: 'r',
        description: 'The list of repositories to build - env: $REPOSITORIES',
        default: process.env.REPOSITORIES
    }),
    repos_path: command_1.flags.string({
        char: 'd',
        description: 'The path where the repositories are installed - env: $REPOS_PATH',
        default: process.env.REPOS_PATH || '.repos'
    })
};
