"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const execa = require("execa");
exports.invalidateCloudfront = (deployPath, cloudfrontDistributionId) => execa('aws', [
    'cloudfront',
    'create-invalidation',
    '--distribution-id',
    cloudfrontDistributionId,
    '--paths',
    deployPath
], {
    shell: true
});
class RepoCloudfront extends command_1.Command {
    async run() {
        const { flags } = this.parse(RepoCloudfront);
        cli_ux_1.default.action.start(`Invalidating Cloudfront cache for path ${flags.deploy_path}`);
        const cloudfrontTask = exports.invalidateCloudfront(flags.deploy_path, flags.cloudfront_distribution_id);
        cloudfrontTask.stderr.pipe(process.stderr);
        cloudfrontTask.stdout.pipe(process.stdout);
        await cloudfrontTask;
        cli_ux_1.default.action.stop();
    }
}
exports.default = RepoCloudfront;
RepoCloudfront.description = 'Invalidate the Cloudfront docs cache for the current repository';
RepoCloudfront.flags = {
    help: command_1.flags.help({ char: 'h' }),
    deploy_path: command_1.flags.string({
        char: 'd',
        description: 'The path where the local version of the docs will be deployed (e.g. /sdk/js/6/) - env: $DEPLOY_PATH',
        default: process.env.DEPLOY_PATH,
        required: true
    }),
    cloudfront_distribution_id: command_1.flags.string({
        char: 'c',
        description: 'The Cloudfront distribution ID where the invalidation will be created - env: $CLOUDFRONT_DISTRIBUTION_ID',
        required: true,
        default: process.env.CLOUDFRONT_DISTRIBUTION_ID
    })
};
